@@ -5,13 +5,13 @@ use rst_parser::parse;
 use crate::html::render_html;
 
 fn check_renders_to(rst: &str, expected: &str) {
-    println!("Rendering:\n{}\n---", rst);
+    println!("Rendering:\n{rst}\n---");
     let doc = parse(rst).expect("Cannot parse");
     let mut result_data: Vec<u8> = vec![];
     render_html(&doc, &mut result_data, false).expect("Render error");
     let result = String::from_utf8(result_data).expect("Could not decode");
     assert_eq!(result.as_str().trim(), expected);
-    println!("{}", expected);
+    println!("{expected}");
 }
 
 #[test]
@@ -74,11 +74,14 @@ reference and the target.</p>\
 
 #[test]
 fn standalone_hyperlinks() {
-    check_renders_to("\
+    check_renders_to(
+        "\
 Some http://url and a not_url_scheme:foo that is not supposed to be an url.
-", "\
+",
+        "\
 <p>Some <a href=\"http://url/\">http://url</a> and a not_url_scheme:foo that is not supposed to be an url.</p>\
-");
+",
+    );
 }
 
 #[test]
@@ -115,6 +118,42 @@ hello ``foo.map(|world| world + 42)``
     );
 }
 
+#[test]
+fn footnote() {
+    // TODO: reference resolution
+    // TODO: auto-numbering over separate blocks
+    check_renders_to(
+        "\
+Footnotes 1: [#]_, 3: [#]_, 33: [33]_, \\*: [*]_, 2: [#named]_, 4: [#]_.
+
+.. [#] Footnote *1*
+.. [33] Footnote *33*
+   More
+.. [#named] Footnote *2*
+.. [#] Footnote *3*
+.. [*] Symbol
+.. [#] Footnote *4*
+",
+        "\
+<p>Footnotes \
+1: <a id=\"footnote-reference-1\" href=\"#footnote-1\">1</a>, \
+3: <a id=\"footnote-reference-2\" href=\"#footnote-3\">3</a>, \
+33: <a id=\"footnote-reference-3\" href=\"#footnote-2\">33</a>, \
+*: <a id=\"footnote-reference-4\" href=\"#footnote-4\" class=\"symbol\"><data value=\"1\">*</data></a>, \
+2: <a id=\"footnote-reference-5\" href=\"#named\">2</a>, \
+4: <a id=\"footnote-reference-6\" href=\"#footnote-5\">4</a>.</p>
+<ol>
+<li id=\"footnote-1\" value=\"1\">[<a href=\"#footnote-reference-1\">1</a>]<p>Footnote <em>1</em></p></li>
+<li id=\"footnote-2\" value=\"33\">[<a href=\"#footnote-reference-3\">33</a>]<p>Footnote <em>33</em></p><p>More</p></li>
+<li id=\"named\" value=\"2\">[<a href=\"#footnote-reference-5\">2</a>]<p>Footnote <em>2</em></p></li>
+<li id=\"footnote-3\" value=\"3\">[<a href=\"#footnote-reference-2\">3</a>]<p>Footnote <em>3</em></p></li>
+<li id=\"footnote-4\" value=\"1\" class=\"symbol\">[<a href=\"#footnote-reference-4\">*</a>]<p>Symbol</p></li>
+<li id=\"footnote-5\" value=\"4\">[<a href=\"#footnote-reference-6\">4</a>]<p>Footnote <em>4</em></p></li>
+</ol>\
+",
+    );
+}
+
 /*
 #[test]
 fn test_section_hierarchy() {
